@@ -155,8 +155,8 @@ class NodePublicConfig(Config):
         Name or number of the node. If not specified, will be set by central server. If not specified, the json file
         should still contain the key 'id', but with value "".
     fitter: str
-        Fitter to use. Can be one of :
-        |  * decisiontree
+        Fitter to use. Can be one of :\n
+          * decisiontree\n
     stop: bool
         Set to True by :class:~ifra.central_server.CentralServer when the learning is over.
     """
